@@ -30,6 +30,7 @@ class RSAKey(AsymmetricKey):
         self._key: Any = None
         self._hash: Any = None
         self._padding: Any = None
+        salt_len: Any = padding.PSS.MAX_LENGTH
 
         # Validate kty.
         if params[1] != 3:
@@ -42,16 +43,17 @@ class RSAKey(AsymmetricKey):
             raise ValueError(f"Unsupported or unknown alg(3) for RSA: {params[3]}.")
         if params[3] == -259 or params[3] == -39:
             self._hash = hashes.SHA512
+            salt_len = 64
         elif params[3] == -258 or params[3] == -38:
             self._hash = hashes.SHA384
+            salt_len = 48
         elif params[3] == -257 or params[3] == -37:
             self._hash = hashes.SHA256
+            salt_len = 32
         else:
             raise ValueError(f"Unsupported or unknown alg(3) for RSA: {params[3]}.")
         if params[3] in [-37, -38, -39]:
-            self._padding = padding.PSS(
-                mgf=padding.MGF1(self._hash()), salt_length=padding.PSS.MAX_LENGTH
-            )
+            self._padding = padding.PSS(mgf=padding.MGF1(self._hash()), salt_length=salt_len)
         else:
             self._padding = padding.PKCS1v15()
 
@@ -60,28 +62,16 @@ class RSAKey(AsymmetricKey):
             if not self._key_ops:
                 self._key_ops = RSAKey._ACCEPTABLE_PUBLIC_KEY_OPS
             else:
-                prohibited = [
-                    ops
-                    for ops in self._key_ops
-                    if ops not in RSAKey._ACCEPTABLE_PUBLIC_KEY_OPS
-                ]
+                prohibited = [ops for ops in self._key_ops if ops not in RSAKey._ACCEPTABLE_PUBLIC_KEY_OPS]
                 if prohibited:
-                    raise ValueError(
-                        f"Unknown or not permissible key_ops(4) for RSAKey: {prohibited[0]}."
-                    )
+                    raise ValueError(f"Unknown or not permissible key_ops(4) for RSAKey: {prohibited[0]}.")
         else:
             if not self._key_ops:
                 self._key_ops = RSAKey._ACCEPTABLE_PRIVATE_KEY_OPS
             else:
-                prohibited = [
-                    ops
-                    for ops in self._key_ops
-                    if ops not in RSAKey._ACCEPTABLE_PRIVATE_KEY_OPS
-                ]
+                prohibited = [ops for ops in self._key_ops if ops not in RSAKey._ACCEPTABLE_PRIVATE_KEY_OPS]
                 if prohibited:
-                    raise ValueError(
-                        f"Unknown or not permissible key_ops(4) for RSAKey: {prohibited[0]}."
-                    )
+                    raise ValueError(f"Unknown or not permissible key_ops(4) for RSAKey: {prohibited[0]}.")
 
         # Validate RSA specific parameters.
         if -1 not in params or not isinstance(params[-1], bytes):
@@ -97,9 +87,7 @@ class RSAKey(AsymmetricKey):
         if -3 not in params:  # the RSA private exponent d.
             private_props = [p for p in params.keys() if p in [-4, -5, -6, -7, -8]]
             if private_props:
-                raise ValueError(
-                    f"RSA public key should not have private parameter: {private_props[0]}."
-                )
+                raise ValueError(f"RSA public key should not have private parameter: {private_props[0]}.")
             self._key = public_numbers.public_key()
             return
 
